#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>

const char* ssid = "SwitchiFy_69648";
const char* password = "";

ESP8266WebServer server(80);

bool status16 = false;
bool status0 = false;
bool status2 = false;

void handleRoot16On() {
  digitalWrite(16, LOW);
  status16 = true;
  Serial.println("");
  Serial.println("16 - Turned on");
  server.send(200, "text/plain", "hello from esp8266 - 16 - On!");
}

void handleRoot16Off() {
  digitalWrite(16, HIGH);
  status16 = false;
  Serial.println("");
  Serial.println("16 - Turned off");
  server.send(200, "text/plain", "hello from esp8266 - 16 - Off!");
}

void handleRoot16Toggle() {
  if (status16){
      handleRoot16Off();
    }
  else{
      handleRoot16On();
    }
}

void handleRoot0Off() {
  digitalWrite(0, HIGH); //Negative Logic
  status0 = false;
  Serial.println("");
  Serial.println("0 - Turned off");
  server.send(200, "text/plain", "hello from esp8266 - 0 - Off!");
}

void handleRoot0On() {
  digitalWrite(0, LOW); //Negative Logic
  status0 = true;
  Serial.println("");
  Serial.println("0 - Turned on");
  server.send(200, "text/plain", "hello from esp8266 - 0 - On!");
}

void handleRoot0Toggle() {
  if (status0){
      handleRoot0Off();
    }
  else{
      handleRoot0On();
    }
}

void handleRoot2Off() {
  digitalWrite(2, HIGH);
  status2 = false;
  Serial.println("");
  Serial.println("2 - Turned off");
  server.send(200, "text/plain", "hello from esp8266 - 2 - Off !");
}

void handleRoot2On() {
  digitalWrite(2, LOW);
  status2 = true;
  Serial.println("");
  Serial.println("2 - Turned on");
  server.send(200, "text/plain", "hello from esp8266 - 2 - On !");
}

void handleRoot2Toggle() {
  if (status2){
      handleRoot2Off();
    }
  else{
      handleRoot2On();
    }
}


void handleNotFound (void);

void setup(void){
  pinMode(16, OUTPUT);
  pinMode(0, OUTPUT);
  pinMode(2, OUTPUT);

  digitalWrite(16,HIGH);
  digitalWrite(0,HIGH);
  digitalWrite(2,HIGH);

  delay(5000);

  digitalWrite(16,LOW);
  digitalWrite(0,LOW);
  digitalWrite(2,LOW);

  
  Serial.begin(115200);
  WiFi.begin(ssid, password);
  Serial.println("");

// Connect to a Wifi Hotspot
//  // Wait for connection
//  while (WiFi.status() != WL_CONNECTED) {
//    delay(500);
//    Serial.print(".");
//  }
//  Serial.println("");
//  Serial.print("Connected to ");
//  Serial.println(ssid);
//  Serial.print("IP address: ");
//  Serial.println(WiFi.localIP());

// Create a wifi hotspot

  Serial.println();
  Serial.print("Configuring access point...");
  /* You can remove the password parameter if you want the AP to be open. */
  WiFi.mode(WIFI_AP);
  WiFi.softAP(ssid, password);

  IPAddress myIP = WiFi.softAPIP();
  Serial.print("AP IP address: ");
  Serial.println(myIP);


  if (MDNS.begin("esp8266")) {
    Serial.println("MDNS responder started");
  }

  server.on("/16/On", handleRoot16On);
  server.on("/16/Off", handleRoot16Off);
  server.on("/16/toggle", handleRoot16Toggle);

  server.on("/0/On", handleRoot0On);
  server.on("/0/Off", handleRoot0Off);
  server.on("/0/toggle", handleRoot0Toggle);

  server.on("/2/On", handleRoot2On);
  server.on("/2/Off", handleRoot2Off);
  server.on("/2/toggle", handleRoot2Toggle);

  server.on("/inline", [](){
    server.send(200, "text/plain", "this works as well");
  });

  server.onNotFound(handleNotFound);

  server.begin();
  Serial.println("HTTP server started");
}

void loop(void){
  server.handleClient();
}


void handleNotFound(){
  digitalWrite(13, HIGH);
  String message = "File Not Found\n\n";
  message += "URI: ";
  message += server.uri();
  message += "\nMethod: ";
  message += (server.method() == HTTP_GET)?"GET":"POST";
  message += "\nArguments: ";
  message += server.args();
  message += "\n";
  for (uint8_t i=0; i<server.args(); i++){
    message += " " + server.argName(i) + ": " + server.arg(i) + "\n";
  }
  server.send(404, "text/plain", message);
  digitalWrite(13, LOW);
}

